@@ -281,7 +281,20 @@ baselineAlgorithms <- list(
                       default = c(NA, NA),
                       max = c(Inf, Inf),
                       incl.max = c(FALSE, FALSE)
-                    ))
+                    )),
+  shirley = new("baselineAlg",
+					name = "shirley",
+					description = "A shirley baseline correction algorithm",
+					funcName = "baseline.shirley",
+					param = data.frame(
+					  name = c("maxit", "err"), # maxit
+					  integer = c(FALSE, FALSE),
+					  min = c(1, 1e-8),
+					  incl.min = c(TRUE, TRUE),
+					  default = c(50, 1e-6),
+					  max = c(Inf, 1e-3),
+					  incl.max = c(FALSE, FALSE)
+					))
   
 ) ## End of baselineAlgorithms <- list(
 
